Learn R Programming

urbnmapr (version 0.0.0.9002)

get_urbn_map: Import different maps

Description

get_urbn_map() loads maps that are different than states and counties

Usage

get_urbn_map(map = "states", sf = FALSE)

Arguments

map

Selection of custom map. Current options are "states", "counties", "ccdf", "territories_states", and "territories_counties".

sf

Option indicates whether data is loaded as a tibble() or an sf object